<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="UTF-8" />
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />
    <link rel="stylesheet" href="{{ prefix }}/static/css/uno.css" />
    <link rel="stylesheet" href="{{ prefix }}/static/css/custom.css" />
    <title>RQ dashboard FastAPI</title>
    <script>
      (function() {
        var stored = localStorage.getItem('theme');
        if (stored === 'dark' || (!stored && window.matchMedia('(prefers-color-scheme: dark)').matches)) {
          document.documentElement.classList.add('dark');
        }
      })();
    </script>
  </head>
  <body class="bg-gray-50 dark:bg-gray-900 text-gray-900 dark:text-gray-200 font-sans min-h-screen flex flex-col">
    {% include "header.html" %}
    <main class="flex-1">{% block content %}{% endblock %}</main>
    {% include "footer.html" %}
  </body>
</html>
