{% extends "base.html" %}{% block content %}
{% if css %}<style>{{ css|safe }}</style>{% endif %}

<div class="max-w-[90%] mx-auto mt-6 px-4">
  <table id="jobs" class="data-table">
    <tr>
      <th class="th-cell">ID</th>
      <td class="td-cell max-w-[600px] overflow-hidden whitespace-normal">{{ job_data.id }}</td>
    </tr>
    <tr>
      <th class="th-cell">Name</th>
      <td class="td-cell max-w-[600px] overflow-hidden whitespace-normal">{{ job_data.name }}</td>
    </tr>
    <tr>
      <th class="th-cell">Created At</th>
      <td class="td-cell max-w-[600px] overflow-hidden whitespace-normal">{{ job_data.created_at }}</td>
    </tr>
    <tr>
      <th class="th-cell">Enqueued At</th>
      <td class="td-cell max-w-[600px] overflow-hidden whitespace-normal">{{ job_data.enqueued_at }}</td>
    </tr>
    <tr>
      <th class="th-cell">Ended At</th>
      <td class="td-cell max-w-[600px] overflow-hidden whitespace-normal">{{ job_data.ended_at }}</td>
    </tr>
    <tr>
      <th class="th-cell">Result</th>
      <td class="td-cell max-w-[600px] overflow-hidden whitespace-normal"><pre class="m-0 whitespace-pre-wrap">{{ job_data.result }}</pre></td>
    </tr>
    <tr>
      <th class="th-cell">Exception Info</th>
      <td class="td-cell max-w-[600px] overflow-hidden whitespace-normal">
        {% if col_exc_info %}{{ col_exc_info|safe }}{% else %}<pre class="m-0 whitespace-pre-wrap">{{ job_data.exc_info }}</pre>{% endif %}
      </td>
    </tr>
    <tr>
      <th class="th-cell">Meta</th>
      <td class="td-cell max-w-[600px] overflow-hidden whitespace-normal">{{ job_data.meta }}</td>
    </tr>
  </table>
  <div class="flex justify-center mt-2.5">
    <a href="javascript:history.back()" class="btn-back">Back</a>
  </div>
</div>
{% endblock %}
