<footer class="border-t border-gray-200 dark:border-gray-700 py-4 mt-8">
  <p class="text-center text-xs text-gray-500 dark:text-gray-500">
    <a href="https://github.com/Hannes221/rq-dashboard-fast" class="text-gray-500 dark:text-gray-500 hover:text-gray-700 dark:hover:text-gray-300 transition-colors">RQ-Dashboard-FastAPI</a>
    &middot; v{{ rq_dashboard_version }}
  </p>
</footer>
